@@ -14,8 +14,10 @@ Jifty::Util - Things that don't fit anywhere else
 
 use Jifty;
 use File::Spec;
+use File::Path;
 use File::ShareDir;
 use UNIVERSAL::require;
+use ExtUtils::MakeMaker ();
 use Cwd ();
 
 # Trivial memoization to ward off evil Cwd calls.
@@ -112,7 +114,7 @@ sub app_root {
         while (@root) {
             my $try = File::Spec->catdir( @root, "bin", "jifty" );
             if (    -e $try
-                and -x $try
+                and (-x $try or MM->maybe_command($try))
                 and $try ne "/usr/bin/jifty"
                 and $try ne "/usr/local/bin/jifty" )
             {
@@ -124,6 +126,7 @@ sub app_root {
     warn "Can't guess application root from current path ("
         . Cwd::cwd()
         . ") or bin path ($FindBin::Bin)\n";
+    return undef;
 }
 
 =head2 default_app_name
@@ -137,11 +140,13 @@ sub default_app_name {
     my $self = shift;
     my @root = File::Spec->splitdir( Jifty::Util->app_root);
     my $name =  pop @root;
-    # Jifty-0.10211 should become Jifty
-    if ($name =~ /^(.*?)-(.*\..*)$/) {
-        $name = $1;
 
-    }
+    # Jifty-0.10211 should become Jifty
+    $name = $1 if $name =~ /^(.*?)-(.*\..*)$/;
+
+    # But don't actually allow "Jifty" as the name
+    $name = "JiftyApp" if lc $name eq "jifty";
+
     return $name;
 }
 
@@ -155,17 +160,7 @@ chain as necessary. (This is what 'mkdir -p' does in your shell)
 sub make_path {
     my $self = shift;
     my $whole_path = shift;
-    my @dirs = File::Spec->splitdir( $whole_path );
-    my $path ='';
-    foreach my $dir ( @dirs) {
-        $path = File::Spec->catdir($path, $dir);
-        if (-d $path) { next }
-        if (-w $path) { die "$path not writable"; }
-        
-        
-        mkdir($path) || die "Couldn't create directory $path: $!";
-    }
-
+    File::Path::mkpath([$whole_path]);
 }
 
 =head2 require PATH
